@@ -122,7 +122,7 @@ class TestPort(network_fakes.TestNetworkV2):
             fake_port.status,
             format_columns.ListColumn(fake_port.tags),
             fake_port.trusted,
-            port.SubPortColumn(fake_port.trunk_details),
+            fake_port.trunk_details,
             fake_port.updated_at,
         )
 
@@ -807,8 +807,7 @@ class TestCreatePort(TestPort):
         extra_dhcp_options = [
             {
                 'opt_name': 'classless-static-route',
-                'opt_value': '169.254.169.254/32,22.2.0.2,'
-                '0.0.0.0/0,22.2.0.1',
+                'opt_value': '169.254.169.254/32,22.2.0.2,0.0.0.0/0,22.2.0.1',
                 'ip_version': '4',
             },
             {
@@ -826,7 +825,7 @@ class TestCreatePort(TestPort):
             '0.0.0.0/0,22.2.0.1,'
             'ip-version=4',
             '--extra-dhcp-option',
-            'name=dns-server,value=240C::6666,' 'ip-version=6',
+            'name=dns-server,value=240C::6666,ip-version=6',
             'test-port',
         ]
 
@@ -1379,7 +1378,7 @@ class TestListPort(compute_fakes.FakeClientMixin, TestPort):
 
     def test_port_list_with_server_option(self):
         fake_server = compute_fakes.create_one_sdk_server()
-        self.compute_sdk_client.find_server.return_value = fake_server
+        self.compute_client.find_server.return_value = fake_server
 
         arglist = [
             '--server',
@@ -1394,7 +1393,7 @@ class TestListPort(compute_fakes.FakeClientMixin, TestPort):
         self.network_client.ports.assert_called_once_with(
             device_id=fake_server.id, fields=LIST_FIELDS_TO_RETRIEVE
         )
-        self.compute_sdk_client.find_server.aassert_called_once_with(
+        self.compute_client.find_server.aassert_called_once_with(
             mock.ANY, 'fake-server-name'
         )
         self.assertEqual(self.columns, columns)
@@ -2633,6 +2632,35 @@ class TestSetPort(TestPort):
     def test_set_trusted_false(self):
         self._test_set_trusted_field(False)
 
+    def _test_set_uplink_status_propagation(self, uspropagation):
+        arglist = [self._port.id]
+        if uspropagation:
+            arglist += ['--enable-uplink-status-propagation']
+        else:
+            arglist += ['--disable-uplink-status-propagation']
+
+        verifylist = [
+            ('port', self._port.id),
+        ]
+        if uspropagation:
+            verifylist.append(('enable_uplink_status_propagation', True))
+        else:
+            verifylist.append(('enable_uplink_status_propagation', False))
+
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        result = self.cmd.take_action(parsed_args)
+        self.network_client.update_port.assert_called_once_with(
+            self._port, **{'propagate_uplink_status': uspropagation}
+        )
+        self.assertIsNone(result)
+
+    def test_set_uplink_status_propagation_true(self):
+        self._test_set_uplink_status_propagation(True)
+
+    def test_set_uplink_status_propagation_false(self):
+        self._test_set_uplink_status_propagation(False)
+
 
 class TestShowPort(TestPort):
     # The port to show.
